package com.github.htfv.maven.plugins.buildconfigurator.core;

import org.apache.maven.project.MavenProject;

import com.github.htfv.maven.plugins.buildconfigurator.model.BCExtensionModel;
import com.github.htfv.maven.plugins.buildconfigurator.model.BCPluginModel;

public class ConfigureRequest
{
    public static class Builder
    {
        private boolean connectorRequest;
        private BCExtensionModel extensionModel;
        private BCPluginModel pluginModel;
        private MavenProject project;

        public ConfigureRequest build()
        {
            return new ConfigureRequest(this);
        }

        public Builder connectorRequest()
        {
            return connectorRequest(true);
        }

        public Builder connectorRequest(final boolean connectorRequest)
        {
            this.connectorRequest = connectorRequest;
            return this;
        }

        public Builder extensionModel(final BCExtensionModel extensionModel)
        {
            this.extensionModel = extensionModel;
            this.pluginModel    = extensionModel;

            return this;
        }

        public Builder pluginModel(final BCPluginModel pluginModel)
        {
            this.extensionModel = null;
            this.pluginModel    = pluginModel;

            return this;
        }

        public Builder project(final MavenProject project)
        {
            this.project = project;
            return this;
        }
    }

    private final boolean connectorRequest;
    private final BCExtensionModel extensionModel;
    private final BCPluginModel pluginModel;
    private final MavenProject project;

    private ConfigureRequest(final Builder builder)
    {
        this.connectorRequest = builder.connectorRequest;
        this.extensionModel   = builder.extensionModel;
        this.pluginModel      = builder.pluginModel;
        this.project          = builder.project;
    }

    public BCExtensionModel getExtensionModel()
    {
        return extensionModel;
    }

    public BCPluginModel getPluginModel()
    {
        return pluginModel;
    }

    public MavenProject getProject()
    {
        return project;
    }

    public boolean isConnectorRequest()
    {
        return connectorRequest;
    }
}
