/*
 * Copyright 2012 htfv (Aliaksei Lahachou)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.htfv.maven.plugins.buildconfigurator.core;

import javax.el.ELContext;

import org.apache.commons.lang3.ObjectUtils;

import com.github.htfv.maven.plugins.buildconfigurator.utils.ELUtils;
import com.github.htfv.maven.plugins.buildconfigurator.utils.MergeUtils.MergeHelper;

/**
 * {@link MergeHelper} which assists in string collection merging.
 *
 * @author htfv (Aliaksei Lahachou)
 */
class StringMergeHelper implements MergeHelper<String, String>
{
    /**
     * {@link ELContext} used to evaluate EL expressions.
     */
    private final ELContext elContext;

    /**
     * Creates a new instance of {@link StringMergeHelper}.
     *
     * @param elContext
     *            {@link ELContext} used to evaluate EL expressions.
     */
    public StringMergeHelper(final ELContext elContext)
    {
        this.elContext = elContext;
    }

    /**
     * Converts the given source {@link String} into a new target {@link String}
     * .
     *
     * @param sourceElement
     *            source {@link String}.
     *
     * @return a new target {@link String}.
     */
    @Override
    public String add(final String sourceElement)
    {
        return ELUtils.getStringValue(elContext, sourceElement);
    }

    /**
     * Updates the given target {@link String} with the given source
     * {@link String}.
     *
     * @param targetElement
     *            target {@link String}.
     * @param sourceElement
     *            source {@link String}.
     *
     * @return {@code true} if the given target and source objects may be
     *         considered equal.
     */
    @Override
    public boolean equals(final String targetElement, final String sourceElement)
    {
        String sourceElementValue = ELUtils.getStringValue(elContext, sourceElement);

        if (ObjectUtils.notEqual(targetElement, sourceElementValue))
        {
            return false;
        }

        return true;
    }

    /**
     * Merges the given source {@link String} into the given target
     * {@link String}.
     *
     * @param targetElement
     *            target {@link String}.
     * @param sourceElement
     *            source {@link String}.
     *
     * @return updated target {@link String}.
     */
    @Override
    public String update(final String targetElement, final String sourceElement)
    {
        return ELUtils.getStringValue(elContext, sourceElement);
    }
}
