/*
 * Copyright 2012 htfv (Aliaksei Lahachou)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.htfv.maven.plugins.buildconfigurator.model;

/**
 * Contains parameters for updating a dependency exclusion.
 *
 * @author htfv (Aliaksei Lahachou)
 */
public class BCExclusion
{
    /**
     * Exclusion is added if it's not yet defined.
     */
    public static final String ACTION_ADD = "add";

    /**
     * Exclusion is skipped.
     */
    public static final String ACTION_SKIP = "skip";

    /**
     * Action to perform with this exclusion; may take one of the following
     * values: {@link BCExclusion#ACTION_ADD}, {@link BCExclusion#ACTION_SKIP}.
     */
    private String action;

    /**
     * {@code artifactId} of the dependency exclusion to update.
     */
    private String artifactId;

    /**
     * {@code groupId} of the dependency exclusion to update.
     */
    private String groupId;

    /**
     * Gets the action to perform with this exclusion; may take one of the
     * following values: {@link BCExclusion#ACTION_ADD},
     * {@link BCExclusion#ACTION_SKIP}.
     *
     * @return action to perform.
     */
    public String getAction()
    {
        return action;
    }

    /**
     * Gets {@code artifactId} of the dependency exclusion to update.
     *
     * @return {@code artifactId} of the dependency exclusion to update.
     */
    public String getArtifactId()
    {
        return artifactId;
    }

    /**
     * Gets {@code groupId} of the dependency exclusion to update.
     *
     * @return {@code groupId} of the dependency exclusion to update.
     */
    public String getGroupId()
    {
        return groupId;
    }

    /**
     * Sets the action to perform with this exclusion; may take one of the
     * following values:
     * <ul>
     * <li>{@link BCExclusion#ACTION_ADD} - exclusion is added if is not yet
     * defined.</li>
     * <li>{@link BCExclusion#ACTION_SKIP} - exclusion is skipped.</li>
     * </ul>
     *
     * @param action
     *            action to perform.
     */
    public void setAction(final String action)
    {
        this.action = action;
    }

    /**
     * Sets {@code artifactId} of the dependency exclusion to update.
     *
     * @param artifactId
     *            {@code artifactId} of the dependency exclusion to update.
     */
    public void setArtifactId(final String artifactId)
    {
        this.artifactId = artifactId;
    }

    /**
     * Gets {@code groupId} of the dependency exclusion to update.
     *
     * @param groupId
     *            {@code groupId} of the dependency exclusion to update.
     */
    public void setGroupId(final String groupId)
    {
        this.groupId = groupId;
    }
}
