/*
 * Copyright 2012 htfv (Aliaksei Lahachou)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.htfv.maven.plugins.buildconfigurator.model;

/**
 * Contains Build Configurator properties.
 *
 * @author htfv (Aliaksei Lahachou)
 */
public class BCProperties
{
    /**
     * Default character encoding used to read property files. Character
     * encoding may be overridden for each loaded property file.
     */
    private String defaultPropertyFilesEncoding;

    /**
     * Flag indicating whether the plugin should be quiet when a property file
     * is not found.
     */
    private String ignoreMissingPropertyFiles;

    /**
     * Gets default character encoding used to read property files. Character
     * encoding may be overridden for each loaded property file.
     *
     * @return default character encoding used to read property files.
     */
    public String getDefaultPropertyFilesEncoding()
    {
        return defaultPropertyFilesEncoding;
    }

    /**
     * Gets the flag indicating whether the plugin should be quiet when a
     * property file is not found.
     *
     * @return flag indicating whether the plugin should be quiet.
     */
    public String getIgnoreMissingPropertyFiles()
    {
        return ignoreMissingPropertyFiles;
    }

    /**
     * Sets default character encoding used to read property files. Character
     * encoding may be overridden for each loaded property file.
     *
     * @param defaultPropertyFilesEncoding
     *            default character encoding used to read property files.
     */
    public void setDefaultPropertyFilesEncoding(final String defaultPropertyFilesEncoding)
    {
        this.defaultPropertyFilesEncoding = defaultPropertyFilesEncoding;
    }

    /**
     * Sets the flag indicating whether the plugin should be quiet when a
     * property file is not found.
     *
     * @param ignoreMissingPropertyFiles
     *            flag indicating whether the plugin should be quiet.
     */
    public void setIgnoreMissingPropertyFiles(final String ignoreMissingPropertyFiles)
    {
        this.ignoreMissingPropertyFiles = ignoreMissingPropertyFiles;
    }
}
