/*
 * Copyright 2012 htfv (Aliaksei Lahachou)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.htfv.maven.plugins.buildconfigurator.model;

/**
 * Contains parameters for loading a property file.
 *
 * @author htfv (Aliaksei Lahachou)
 */
public class BCPropertyFile
{
    /**
     * Character encoding used to read the property file. If this property is
     * {@code null}, default encoding should be used.
     */
    private String encoding;

    /**
     * Path to the property file to load (relative to ${project.basedir}). This
     * property should not be {@code null}.
     */
    private String file;

    /**
     * Specifies whether the file should be skipped if it does not exist. If
     * this property is {@code null}, default value should be used.
     */
    private String ignoreMissing;

    /**
     * Gets character encoding used to read the property file. If this property
     * is {@code null}, default encoding should be used.
     *
     * @return character encoding used to read the property file.
     */
    public String getEncoding()
    {
        return encoding;
    }

    /**
     * Gets path to the property file to load (relative to ${project.basedir}).
     * This property should not be {@code null}.
     *
     * @return path to the property file to load (relative to
     *         ${project.basedir}).
     */
    public String getFile()
    {
        return file;
    }

    /**
     * Gets value specifying whether the file should be skipped if it does not
     * exist. If this property is {@code null}, default value should be used.
     *
     * @return value specifying whether the file should be skipped if it does
     *         not exist.
     */
    public String getIgnoreMissing()
    {
        return ignoreMissing;
    }

    /**
     * Sets character encoding used to read the property file. This property may
     * be set to {@code null} if default encoding should be used.
     *
     * @param encoding
     *            character encoding used to read the property file.
     */
    public void setEncoding(final String encoding)
    {
        this.encoding = encoding;
    }

    /**
     * Sets path to the property file to load (relative to ${project.basedir}).
     * This property should not be {@code null}.
     *
     * @param file
     *            path to the property file to load (relative to
     *            ${project.basedir}).
     */
    public void setFile(final String file)
    {
        this.file = file;
    }

    /**
     * Sets value specifying whether the file should be skipped if it does not
     * exist. This property may be set to {@code null} if default value should
     * be used.
     *
     * @param ignoreMissing
     *            value specifying whether the file should be skipped if it does
     *            not exist.
     */
    public void setIgnoreMissing(final String ignoreMissing)
    {
        this.ignoreMissing = ignoreMissing;
    }
}
