package com.github.htfv.maven.plugins.buildconfigurator.utils;

import javax.el.ELContext;

import com.github.htfv.maven.plugins.buildconfigurator.el.DefaultExpressionFactory;

/**
 * Contains utility methods for working with EL expressions.
 *
 * @author htfv (Aliaksei Lahachou)
 */
public abstract class ELUtils
{
    /**
     * Evaluates EL value expression using default expression factory.
     *
     * @param elContext
     *            {@link ELContext} used to evaluate EL expressions.
     * @param expression
     *            the expression to evaluate.
     *
     * @return the result of the expression evaluation.
     */
    public static Boolean getBooleanValue(final ELContext elContext, final String expression)
    {
        return getValue(elContext, expression, Boolean.class);
    }

    /**
     * Evaluates EL value expression using default expression factory.
     *
     * @param elContext
     *            {@link ELContext} used to evaluate EL expressions.
     * @param expression
     *            the expression to evaluate.
     *
     * @return the result of the expression evaluation.
     */
    public static String getStringValue(final ELContext elContext, final String expression)
    {
        return getValue(elContext, expression, String.class);
    }

    /**
     * Evaluates EL value expression using default expression factory.
     *
     * @param <T>
     *            the type the result of the expression will be coerced to after
     *            evaluation.
     *
     * @param elContext
     *            {@link ELContext} used to evaluate EL expressions.
     * @param expression
     *            the expression to evaluate.
     * @param expectedType
     *            the type the result of the expression will be coerced to after
     *            evaluation.
     *
     * @return the result of the expression evaluation.
     */
    @SuppressWarnings("unchecked")
    public static <T> T getValue(final ELContext elContext, final String expression,
            final Class<T> expectedType)
    {
        if (expression == null)
        {
            return null;
        }

        return (T) DefaultExpressionFactory.getInstance()
                .createValueExpression(elContext, expression, expectedType)
                .getValue(elContext);
    }
}
